# django-chile-payments

**Online payments, "the chilean way"**. A django app with a flexible architecture designed to be multi-broker payment processor. Originally developed with love at [Nomadblue](http://www.nomadblue.com).

For now it only sports the *"peso pesado"* of online payments in Chile, an old folk well-known by local developers called [Webpay Plus](https://www.transbank.cl/public/pagina_producto_11.html) from **Transbank**. In the close future, we plan to include other APIs (e.g. [DineroMail](https://cl.dineromail.com/desarrolladores/biblioteca) or [Servipag](https://www.servipag.com/Portal-De-Pagos-En-Linea/Home/botondepago)), eventually becoming a de-facto package for Django payment processing in Chile.

## Documentation

Read it online [here](http://nomadblue.viewdocs.io/django-chile-payments) or directly from the ['docs/'](https://github.com/Nomadblue/django-chile-payments/tree/master/docs) folder in the source code.
